diff Core/SQLite/Statement.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents db4d996ea264
children c996319e90bc
line wrap: on
line diff
--- a/Core/SQLite/Statement.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/Core/SQLite/Statement.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -43,7 +43,7 @@
 #include <sqlite3.h>
 #include <string.h>
 
-namespace Palantir
+namespace Palanthir
 {
   namespace SQLite
   {
@@ -52,7 +52,7 @@
       bool succeeded = (err == SQLITE_OK || err == SQLITE_ROW || err == SQLITE_DONE);
       if (!succeeded)
       {
-        throw PalantirException("SQLite error code " + boost::lexical_cast<std::string>(err));
+        throw PalanthirException("SQLite error code " + boost::lexical_cast<std::string>(err));
       }
 
       return err;
@@ -63,11 +63,11 @@
       if (err == SQLITE_RANGE)
       {
         // Binding to a non-existent variable is evidence of a serious error.
-        throw PalantirException("Bind value out of range");
+        throw PalanthirException("Bind value out of range");
       }
       else if (err != SQLITE_OK)
       {
-        throw PalantirException("SQLite error code " + boost::lexical_cast<std::string>(err));
+        throw PalanthirException("SQLite error code " + boost::lexical_cast<std::string>(err));
       }
     }
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium